/***************************************************************************
*   KBlocks, a falling blocks game by KDE                                 *
*   Copyright (C) 2010 University Freiburg <squall.leonhart.cai@gmail.com> *
*                                                                          *
*   This program is free software; you can redistribute it and/or modify   *
*   it under the terms of the GNU General Public License as published by   *
*   the Free Software Foundation; either version 2 of the License, or      *
*   (at your option) any later version.                                    *
***************************************************************************/
#ifndef KBLOCKSAITYPEDEFINE_H
#define KBLOCKSAITYPEDEFINE_H

#include <utility>
#include <stdlib.h>

#define KSIRTET

#define INITLIST

#ifndef DEBUG
#define DEBUG
#endif

#ifndef LOG
#define LOG
#endif

#define UNIX

#endif
